aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/dyndep.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/dyndep.cxx')
-rw-r--r--libbuild2/dyndep.cxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/libbuild2/dyndep.cxx b/libbuild2/dyndep.cxx
index 47c6396..727a28c 100644
--- a/libbuild2/dyndep.cxx
+++ b/libbuild2/dyndep.cxx
@@ -30,11 +30,11 @@ namespace build2
bool adhoc,
uintptr_t data)
{
// Even if failing we still use try_match() in order to issue consistent
// (with other places) diagnostics (rather than the generic "not rule to
// update ...").
//
- if (!try_match (a, pt).first)
+ if (!try_match_sync (a, pt).first)
{
if (!f)
return nullopt;
@@ -65,7 +65,7 @@ namespace build2
bool adhoc,
uintptr_t data)
{
- if (!try_match (a, pt).first)
+ if (!try_match_sync (a, pt).first)
{
if (!f)
return nullopt;
@@ -30,11 +30,11 @@ namespace build2
uintptr_t data)
{
- // Even if failing we still use try_match() in order to issue consistent
- // (with other places) diagnostics (rather than the generic "not rule to
- // update ...").
+ // Even if failing we still use try_match_sync() in order to issue
+ // consistent (with other places) diagnostics (rather than the generic
+ // "not rule to update ...").
//